oriole_service package — Oriole-service 4.6.2 documentation

Oriole-service 4.6.2 documentation

# oriole_service package

## Subpackages

- oriole_service.modules package
  - Submodules
  - oriole_service.modules.conf module
  - oriole_service.modules.doc module
  - oriole_service.modules.halt module
  - oriole_service.modules.run module
  - oriole_service.modules.sh module
  - oriole_service.modules.test module
  - Module contents

## Submodules

## oriole_service.api module

`oriole_service.api.` `Config`(name='services.cfg')

  Obsoleted

`oriole_service.api.` `check`(f)

`oriole_service.api.` `conf`(name)

`oriole_service.api.` `cwd`()

`oriole_service.api.` `exe`(s)

`oriole_service.api.` `get_cfg`(f)

`oriole_service.api.` `get_config`(f='services.cfg')

`oriole_service.api.` `get_file`(f)

`oriole_service.api.` `get_first`(s)

`oriole_service.api.` `get_logger`()

`oriole_service.api.` `get_path`(f, loc)

`oriole_service.api.` `get_yml`(f)

`oriole_service.api.` `halt`(service)

`oriole_service.api.` `logger`(level='DEBUG', name='')

`oriole_service.api.` `mexe`(f, s)

`oriole_service.api.` `mtest`(test)

`oriole_service.api.` `remote_test`(f)

`oriole_service.api.` `run`(service)

`oriole_service.api.` `test`(tests)

## oriole_service.app module

class `oriole_service.app.` `App`

  Bases: `object`

  Connect database

  As usual, supply mysql and redis.

  `db` = <Db [unbound]>
  `init`()

    Noop

  `log` = <Logger services (DEBUG)>
  `name` = 'supervisor_thread'
  `obj2dict`(obj)

    Don’t use it!

  `ping`()
  `rs` = <Rs [unbound]>
  `ver` = '1.0.0'
  `version`()

## oriole_service.cli module

`oriole_service.cli.` `add_parser`(parser, modules)

`oriole_service.cli.` `main`()

`oriole_service.cli.` `setup_parser`()

`oriole_service.cli.` `setup_yaml_parser`()

## oriole_service.db module

class `oriole_service.db.` `Db`(Base)

  Bases: `nameko.extensions.DependencyProvider`

  `get_dependency`(worker_ctx)
  `setup`()
  `stop`()
  `worker_teardown`(worker_ctx)

class `oriole_service.db.` `Rs`

  Bases: `nameko.extensions.DependencyProvider`

  `get_dependency`(worker_ctx)
  `setup`()

## oriole_service.log module

class `oriole_service.log.` `Log`(module='')

  Bases: `object`

  `get`()

## oriole_service.test module

`oriole_service.test.` `app`(monkeypatch)

## Module contents